/*
 * Author:   DONGSK
 * Datetime: 2023/6/30 19:57
 * Description:
 * History:
 * 作者姓名 --修改时间 --版本号--描述
 */
package com.digiwin.athena.app.service.cps;

import com.alibaba.fastjson.TypeReference;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.entity.CpsQuestionInfo;
import com.digiwin.athena.app.infra.service.CpsQuestionInfoService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.persistence.domain.BaseMgrEntity;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * CpsQuestionUpdateService
 *
 * @author DONGSK 2023/6/30 19:57
 * @since 1.0.0
 */
@Service
public class CpsQuestionGetService extends AbsEAIService {

    @Resource
    CpsQuestionInfoService cpsQuestionInfoService;

    @Override
    public String getServiceName() {
        return CpsUtil.CPS_QUESTION_INFO_GET;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {

        EAIRequest eaiRequest = new EAIRequest(messageBody);

        String option = eaiRequest.getString("option");

        // 侦测
        if (StringUtils.isBlank(option)) {

            List<CpsQuestionInfo> list = cpsQuestionInfoService.lambdaQuery().eq(CpsQuestionInfo::getStatus, 0).list();
            list.forEach(o -> {
                o.setStatus(1);
            });
            cpsQuestionInfoService.updateBatchById(list);
            return buildOK("change_objects", list);
        }

        // 任务卡查询
        List<CpsQuestionInfo> questionInfo = eaiRequest.getObject("question_info", new TypeReference<List<CpsQuestionInfo>>() {
        });

        List<Long> collectIds = questionInfo.stream().map(BaseMgrEntity::getId).collect(Collectors.toList());

        LambdaQueryChainWrapper<CpsQuestionInfo> lambdaQuery = cpsQuestionInfoService.lambdaQuery().in(CpsQuestionInfo::getId, collectIds);

        String status = eaiRequest.getString("status");
        switch (option) {
            case "1":
                lambdaQuery.eq(CpsQuestionInfo::getStatus1, status);
                break;
            case "2":
                lambdaQuery.eq(CpsQuestionInfo::getStatus2, status);
                break;
            case "3":
                lambdaQuery.eq(CpsQuestionInfo::getStatus3, status);
                break;
            case "4":
                lambdaQuery.eq(CpsQuestionInfo::getStatus4, status);
                break;
            case "5":
                lambdaQuery.eq(CpsQuestionInfo::getStatus5, status);
                break;
            case "6":
                lambdaQuery.eq(CpsQuestionInfo::getStatus6, status);
                break;
        }

        return buildOK("question_info", lambdaQuery.list());
    }
}
